@@ -1,14 +1,14 @@
 #include "vcf2genoLoader.h"
 
-#include <string>
 #include <map>
-#include <vector>
 #include <set>
+#include <string>
+#include <vector>
 
+#include "R_CPP_interface.h"
+#include "TabixReader.h"
 #include "VCFUtil.h"
 #include "tabix.h"
-#include "TabixReader.h"
-#include "R_CPP_interface.h"
 
 #include <R.h>
 
@@ -27,7 +27,7 @@ SEXP readVCF2Matrix(VCFExtractor* vin) {
   std::vector<std::string>& names = idVec;
   vin->getVCFHeader()->getPeopleName(&names);
 
-  while (vin->readRecord()){
+  while (vin->readRecord()) {
     // REprintf("read a record\n");
     VCFRecord& r = vin->getVCFRecord();
     VCFPeople& people = r.getPeople();
@@ -42,28 +42,29 @@ SEXP readVCF2Matrix(VCFExtractor* vin) {
     for (size_t i = 0; i < people.size(); i++) {
       indv = people[i];
       int g = indv->justGet(0).getGenotype();
-      //Rprintf( "\t%d", g);
+      // Rprintf( "\t%d", g);
       genoVec.push_back(g);
     }
-    //Rprintf( "\n");
-  }; // end while
+    // Rprintf( "\n");
+  };  // end while
 
-  //  REprintf("posVec = %zu, idVec = %zu, genoVec = %zu\n", posVec.size(), idVec.size(), genoVec.size());
+  //  REprintf("posVec = %zu, idVec = %zu, genoVec = %zu\n", posVec.size(),
+  //  idVec.size(), genoVec.size());
 
   // pass value back to R (see Manual Chapter 5)
 
-
-  int nx = (int) posVec.size();
-  int ny = (int) idVec.size();
+  int nx = (int)posVec.size();
+  int ny = (int)idVec.size();
 
   SEXP ans = R_NilValue;
 
   PROTECT(ans = allocMatrix(REALSXP, nx, ny));
   double* rans = REAL(ans);
   int idx = 0;
-  for(int i = 0; i < nx; i++) {
-    for(int j = 0; j <ny ; j++ ) {
-      // Rprintf("idx = %d, i = %d, j=%d, geno = %g\n", idx, i, j, genoVec[idx]);
+  for (int i = 0; i < nx; i++) {
+    for (int j = 0; j < ny; j++) {
+      // Rprintf("idx = %d, i = %d, j=%d, geno = %g\n", idx, i, j,
+      // genoVec[idx]);
       rans[i + nx * j] = genoVec[idx];
       ++idx;
     }
@@ -72,16 +73,17 @@ SEXP readVCF2Matrix(VCFExtractor* vin) {
   // set row and col names
   SEXP dim;
   PROTECT(dim = allocVector(INTSXP, 2));
-  INTEGER(dim)[0] = nx; INTEGER(dim)[1] = ny;
+  INTEGER(dim)[0] = nx;
+  INTEGER(dim)[1] = ny;
   setAttrib(ans, R_DimSymbol, dim);
 
   SEXP rowName;
-  PROTECT(rowName=allocVector(STRSXP, nx));
-  for (int i = 0; i < nx; i++ )
+  PROTECT(rowName = allocVector(STRSXP, nx));
+  for (int i = 0; i < nx; i++)
     SET_STRING_ELT(rowName, i, mkChar(posVec[i].c_str()));
   SEXP colName;
-  PROTECT(colName=allocVector(STRSXP, ny));
-  for (int i = 0; i < ny; i++ )
+  PROTECT(colName = allocVector(STRSXP, ny));
+  for (int i = 0; i < ny; i++)
     SET_STRING_ELT(colName, i, mkChar(idVec[i].c_str()));
 
   SEXP dimnames;
@@ -92,15 +94,15 @@ SEXP readVCF2Matrix(VCFExtractor* vin) {
 
   // finish up
   UNPROTECT(5);
-  return(ans);
-} // end readVCF2Matrix
+  return (ans);
+}  // end readVCF2Matrix
 
 /**
  * @param file name
  * @return check whether VCF files has ANNO tag
  */
 bool vcfHasAnnotation(const std::string& fn) {
-  //Rprintf( "range = %s\n", range.c_str());
+  // Rprintf( "range = %s\n", range.c_str());
   VCFInputFile vin(fn);
   while (vin.readRecord()) {
     VCFRecord& r = vin.getVCFRecord();
@@ -118,16 +120,19 @@ bool vcfHasAnnotation(const std::string& fn) {
 /**
  * @param arg_fileName: a string character
  * @param arg_geneFile: which gene file to use
- * @param arg_geneName: which gene we are interested. (just allow One gene name).
- * @param arg_annoType: allow annotation type, can be regular expression. (e.g. Synonymous|Nonsynonymous)
+ * @param arg_geneName: which gene we are interested. (just allow One gene
+ * name).
+ * @param arg_annoType: allow annotation type, can be regular expression. (e.g.
+ * Synonymous|Nonsynonymous)
  */
-SEXP impl_readVCFToMatrixByRange(SEXP arg_fileName, SEXP arg_range, SEXP arg_annoType) {
+SEXP impl_readVCFToMatrixByRange(SEXP arg_fileName, SEXP arg_range,
+                                 SEXP arg_annoType) {
   SEXP ans = R_NilValue;
 
-  std::string FLAG_fileName = CHAR(STRING_ELT(arg_fileName,0));
+  std::string FLAG_fileName = CHAR(STRING_ELT(arg_fileName, 0));
   std::vector<std::string> FLAG_range;
   extractStringArray(arg_range, &FLAG_range);
-  std::string FLAG_annoType = CHAR(STRING_ELT(arg_annoType,0));
+  std::string FLAG_annoType = CHAR(STRING_ELT(arg_annoType, 0));
 
   if (FLAG_fileName.size() == 0) {
     error("Please provide VCF file name");
@@ -139,7 +144,9 @@ SEXP impl_readVCFToMatrixByRange(SEXP arg_fileName, SEXP arg_range, SEXP arg_ann
   }
 
   if (!FLAG_annoType.empty() && !vcfHasAnnotation(FLAG_fileName)) {
-    REprintf("Please use annotated VCF as input (cannot find ANNO in the INFO field);\n");
+    REprintf(
+        "Please use annotated VCF as input (cannot find ANNO in the INFO "
+        "field);\n");
     REprintf("Prefer using ANNO from https://github.com/zhanxw/anno  \n");
     return ans;
   }
@@ -147,12 +154,12 @@ SEXP impl_readVCFToMatrixByRange(SEXP arg_fileName, SEXP arg_range, SEXP arg_ann
   int nGene = FLAG_range.size();
   Rprintf("%d region to be extracted.\n", nGene);
   int numAllocated = 0;
-  
+
   // allocate return value
   PROTECT(ans = allocVector(VECSXP, nGene));
   numAllocated++;
-  numAllocated += setListNames(FLAG_range, &ans);
-  
+  setListNames(FLAG_range, &ans);
+
   for (int i = 0; i < nGene; ++i) {
     // REprintf("range = %s\n", FLAG_range[i].c_str());
     VCFExtractor vin(FLAG_fileName.c_str());
@@ -166,22 +173,25 @@ SEXP impl_readVCFToMatrixByRange(SEXP arg_fileName, SEXP arg_range, SEXP arg_ann
   }
   UNPROTECT(numAllocated);
   return ans;
-} //end impl_readVCFToMatrixByRange
+}  // end impl_readVCFToMatrixByRange
 
 /**
  * @param arg_fileName: a string character
  * @param arg_geneFile: which gene file to use
- * @param arg_geneName: which gene we are interested. (just allow One gene name).
- * @param arg_annoType: allow annotation type, can be regular expression. (e.g. Synonymous|Nonsynonymous)
+ * @param arg_geneName: which gene we are interested. (just allow One gene
+ * name).
+ * @param arg_annoType: allow annotation type, can be regular expression. (e.g.
+ * Synonymous|Nonsynonymous)
  */
-SEXP impl_readVCFToMatrixByGene(SEXP arg_fileName, SEXP arg_geneFile, SEXP arg_geneName, SEXP arg_annoType) {
+SEXP impl_readVCFToMatrixByGene(SEXP arg_fileName, SEXP arg_geneFile,
+                                SEXP arg_geneName, SEXP arg_annoType) {
   SEXP ans = R_NilValue;
 
-  std::string FLAG_fileName = CHAR(STRING_ELT(arg_fileName,0));
-  std::string FLAG_geneFile = CHAR(STRING_ELT(arg_geneFile,0));
+  std::string FLAG_fileName = CHAR(STRING_ELT(arg_fileName, 0));
+  std::string FLAG_geneFile = CHAR(STRING_ELT(arg_geneFile, 0));
   std::vector<std::string> FLAG_geneName;
   extractStringArray(arg_geneName, &FLAG_geneName);
-  std::string FLAG_annoType = CHAR(STRING_ELT(arg_annoType,0));
+  std::string FLAG_annoType = CHAR(STRING_ELT(arg_annoType, 0));
 
   if (FLAG_fileName.size() == 0) {
     error("Please provide VCF file name");
@@ -190,7 +200,9 @@ SEXP impl_readVCFToMatrixByGene(SEXP arg_fileName, SEXP arg_geneFile, SEXP arg_g
     error("Please provide gene file name when extract genotype by gene");
   }
   if (!FLAG_annoType.empty() && !vcfHasAnnotation(FLAG_fileName)) {
-    REprintf("Please use annotated VCF as input (cannot find ANNO in the INFO field);\n");
+    REprintf(
+        "Please use annotated VCF as input (cannot find ANNO in the INFO "
+        "field);\n");
     REprintf("Prefer using ANNO from https://github.com/zhanxw/anno  \n");
     return ans;
   }
@@ -198,24 +210,25 @@ SEXP impl_readVCFToMatrixByGene(SEXP arg_fileName, SEXP arg_geneFile, SEXP arg_g
   int nGene = FLAG_geneName.size();
   Rprintf("%d region to be extracted.\n", nGene);
   int numAllocated = 0;
-  
+
   // allocate return value
   PROTECT(ans = allocVector(VECSXP, nGene));
   numAllocated++;
-  numAllocated += setListNames(FLAG_geneName, &ans);
+  setListNames(FLAG_geneName, &ans);
 
-  OrderedMap< std::string, std::string> geneRange;
-  loadGeneFile(FLAG_geneFile, FLAG_geneName, &geneRange);  
+  OrderedMap<std::string, std::string> geneRange;
+  loadGeneFile(FLAG_geneFile, FLAG_geneName, &geneRange);
   for (int i = 0; i < nGene; ++i) {
     // REprintf("range = %s\n", FLAG_geneName[i].c_str());
     const std::string& range = geneRange[FLAG_geneName[i]];
 
-    //Rprintf( "range = %s\n", range.c_str());
+    // Rprintf( "range = %s\n", range.c_str());
     VCFExtractor vin(FLAG_fileName.c_str());
     if (range.size())
       vin.setRangeList(range.c_str());
     else {
-      warning("Gene name [ %s ] does not exists in provided gene file", FLAG_geneName[i].c_str());
+      warning("Gene name [ %s ] does not exists in provided gene file",
+              FLAG_geneName[i].c_str());
       UNPROTECT(numAllocated);
       return (ans);
     };
@@ -239,15 +252,17 @@ SEXP readVCF2List(VCFInputFile* vin,
   // Rprintf("vcfInfo.size() = %u\n", FLAG_infoTag.size());
   // Rprintf("vcfIndv.size() = %u\n", FLAG_indvTag.size());
   // also append sample names at the end
-  int retListLen = FLAG_vcfColumn.size() + FLAG_infoTag.size() + FLAG_indvTag.size() + 1;
+  int retListLen =
+      FLAG_vcfColumn.size() + FLAG_infoTag.size() + FLAG_indvTag.size() + 1;
   if (retListLen == 0) {
     return R_NilValue;
   }
 
-  int numAllocated = 0; // record how many times we allocate (using PROTECT in R);
+  int numAllocated =
+      0;  // record how many times we allocate (using PROTECT in R);
   SEXP ret;
   PROTECT(ret = allocVector(VECSXP, retListLen));
-  numAllocated ++;
+  numAllocated++;
 
   //  store results
   std::vector<std::string> idVec;
@@ -268,17 +283,16 @@ SEXP readVCF2List(VCFInputFile* vin,
   // std::vector<int> gqVec;
 
   std::map<std::string, std::vector<std::string> > indvMap;
-  int nRow = 0; // # of positions that will be outputed
+  int nRow = 0;  // # of positions that will be outputed
 
   // print header
   std::vector<std::string>& names = idVec;
   vin->getVCFHeader()->getPeopleName(&names);
 
-
   bool FLAG_variantOnly = false;
   // real working part
   int nonVariantSite = 0;
-  while (vin->readRecord()){
+  while (vin->readRecord()) {
     // REprintf("read a record\n");
     VCFRecord& r = vin->getVCFRecord();
     VCFPeople& people = r.getPeople();
@@ -288,11 +302,10 @@ SEXP readVCF2List(VCFInputFile* vin,
       bool hasVariant = false;
       int geno;
       int GTidx = r.getFormatIndex("GT");
-      for (size_t i = 0; i < people.size() ;i ++) {
+      for (size_t i = 0; i < people.size(); i++) {
         indv = people[i];
         geno = indv->justGet(GTidx).getGenotype();
-        if (geno != 0 && geno != MISSING_GENOTYPE)
-          hasVariant = true;
+        if (geno != 0 && geno != MISSING_GENOTYPE) hasVariant = true;
       }
       if (!hasVariant) {
         nonVariantSite++;
@@ -302,42 +315,43 @@ SEXP readVCF2List(VCFInputFile* vin,
 
     // store results here
     nRow++;
-    if (FLAG_vcfColumn.count("CHROM")){
+    if (FLAG_vcfColumn.count("CHROM")) {
       chrom.push_back(r.getChrom());
     }
-    if (FLAG_vcfColumn.count("POS")){
+    if (FLAG_vcfColumn.count("POS")) {
       pos.push_back(r.getPos());
     }
-    if (FLAG_vcfColumn.count("ID")){
+    if (FLAG_vcfColumn.count("ID")) {
       rsId.push_back(r.getID());
     }
-    if (FLAG_vcfColumn.count("REF")){
+    if (FLAG_vcfColumn.count("REF")) {
       ref.push_back(r.getRef());
     }
-    if (FLAG_vcfColumn.count("ALT")){
+    if (FLAG_vcfColumn.count("ALT")) {
       alt.push_back(r.getAlt());
     }
-    if (FLAG_vcfColumn.count("QUAL")){
+    if (FLAG_vcfColumn.count("QUAL")) {
       qual.push_back(r.getQual());
     }
-    if (FLAG_vcfColumn.count("FILTER")){
+    if (FLAG_vcfColumn.count("FILTER")) {
       filt.push_back(r.getFilt());
     }
-    if (FLAG_vcfColumn.count("INFO")){
+    if (FLAG_vcfColumn.count("INFO")) {
       info.push_back(r.getInfo());
     }
-    if (FLAG_vcfColumn.count("FORMAT")){
+    if (FLAG_vcfColumn.count("FORMAT")) {
       format.push_back(r.getFormat());
     }
 
     // store INFO field
-    for (std::vector<std::string>::const_iterator it = FLAG_infoTag.begin(); it != FLAG_infoTag.end(); ++it) {
+    for (std::vector<std::string>::const_iterator it = FLAG_infoTag.begin();
+         it != FLAG_infoTag.end(); ++it) {
       bool missing;
       VCFValue v = r.getInfoTag(it->c_str(), &missing);
       if (missing) {
-        infoMap[ *it ].push_back("");
+        infoMap[*it].push_back("");
       } else {
-        infoMap[ *it ].push_back(v.toStr());
+        infoMap[*it].push_back(v.toStr());
         // Rprintf("add info field [ %s ] = %s\n", it->c_str(), v.toStr());
       }
     };
@@ -347,86 +361,87 @@ SEXP readVCF2List(VCFInputFile* vin,
     for (size_t i = 0; i < people.size(); i++) {
       indv = people[i];
 
-      for (std::vector<std::string>::const_iterator it = FLAG_indvTag.begin(); it != FLAG_indvTag.end(); ++it) {
+      for (std::vector<std::string>::const_iterator it = FLAG_indvTag.begin();
+           it != FLAG_indvTag.end(); ++it) {
         int idx = r.getFormatIndex(it->c_str());
         if (idx < 0) {
-          indvMap[ *it ].push_back("");
+          indvMap[*it].push_back("");
         } else {
           bool missing;
           VCFValue v = indv->get(idx, &missing);
           if (missing) {
-            indvMap[ *it ].push_back("");
-          } else{
-            indvMap[ *it ].push_back(v.toStr());
+            indvMap[*it].push_back("");
+          } else {
+            indvMap[*it].push_back(v.toStr());
             // Rprintf("add indv field [ %s ] = %s\n", it->c_str(), v.toStr());
           }
         }
       };
     }
     // Rprintf("Done add indv\n");
-  }; // end while
+  };  // end while
   //   Rprintf("indvMap.size() = %zu\n", indvMap.size());
-  // REprintf("posVec = %zu, idVec = %zu, genoVec = %zu\n", posVec.size(), idVec.size(), genoVec.size());
+  // REprintf("posVec = %zu, idVec = %zu, genoVec = %zu\n", posVec.size(),
+  // idVec.size(), genoVec.size());
 
   // pass value back to R (see Manual Chapter 5)
   std::vector<std::string> listNames;
   int retListIdx = 0;
   if (FLAG_vcfColumn.count("CHROM")) {
-    numAllocated += storeResult(chrom, ret, retListIdx++);
+    storeResult(chrom, ret, retListIdx++);
     listNames.push_back("CHROM");
   }
   if (FLAG_vcfColumn.count("POS")) {
-    numAllocated += storeResult(pos, ret, retListIdx++);
+    storeResult(pos, ret, retListIdx++);
     listNames.push_back("POS");
   }
-  if (FLAG_vcfColumn.count("ID"))  {
-    numAllocated += storeResult(rsId, ret, retListIdx++);
+  if (FLAG_vcfColumn.count("ID")) {
+    storeResult(rsId, ret, retListIdx++);
     listNames.push_back("ID");
   }
   if (FLAG_vcfColumn.count("REF")) {
-    numAllocated += storeResult(ref, ret, retListIdx++);
+    storeResult(ref, ret, retListIdx++);
     listNames.push_back("REF");
   }
   if (FLAG_vcfColumn.count("ALT")) {
-    numAllocated += storeResult(alt, ret, retListIdx++);
+    storeResult(alt, ret, retListIdx++);
     listNames.push_back("ALT");
   }
   if (FLAG_vcfColumn.count("QUAL")) {
-    numAllocated += storeResult(qual, ret, retListIdx++);
+    storeResult(qual, ret, retListIdx++);
     listNames.push_back("QUAL");
   }
   if (FLAG_vcfColumn.count("FILTER")) {
-    numAllocated += storeResult(filt, ret, retListIdx++);
+    storeResult(filt, ret, retListIdx++);
     listNames.push_back("FILTER");
   }
   if (FLAG_vcfColumn.count("INFO")) {
-    numAllocated += storeResult(info, ret, retListIdx++);
+    storeResult(info, ret, retListIdx++);
     listNames.push_back("INFO");
   }
   if (FLAG_vcfColumn.count("FORMAT")) {
-    numAllocated += storeResult(format, ret, retListIdx++);
+    storeResult(format, ret, retListIdx++);
     listNames.push_back("FORMAT");
   }
   // pass info values to R
-  for ( std::map<std::string, std::vector<std::string> >::iterator it = infoMap.begin();
-        it != infoMap.end();
-        ++it) {
-    numAllocated += storeResult(it->first, it->second, ret, retListIdx++);
+  for (std::map<std::string, std::vector<std::string> >::iterator it =
+           infoMap.begin();
+       it != infoMap.end(); ++it) {
+    storeResult(it->first, it->second, ret, retListIdx++);
     listNames.push_back(it->first);
   }
   // pass indv tags to R
   // Rprintf("pass idnv tags\n");
-  for ( std::map<std::string, std::vector<std::string> >::iterator it = indvMap.begin();
-        it != indvMap.end();
-        ++it) {
-
+  for (std::map<std::string, std::vector<std::string> >::iterator it =
+           indvMap.begin();
+       it != indvMap.end(); ++it) {
     // dump(it->second);
-    numAllocated += storeResult(it->first, it->second, ret, retListIdx);
+    storeResult(it->first, it->second, ret, retListIdx);
     // Rprintf("results done\n");
     // NOTE: R internally store values into matrix by column first!
     // thus the matrix is people by marker
-    numAllocated += setDim(idVec.size(), nRow, ret, retListIdx);
-    retListIdx ++;
+    setDim(idVec.size(), nRow, ret, retListIdx);
+    retListIdx++;
     listNames.push_back(it->first);
   }
   // Rprintf("pass idnv tags done.\n");
@@ -434,13 +449,13 @@ SEXP readVCF2List(VCFInputFile* vin,
   // store sample ids
   // Rprintf("set sample id");
   listNames.push_back("sampleId");
-  numAllocated += storeResult(idVec, ret, retListIdx++);
+  storeResult(idVec, ret, retListIdx++);
 
   // Rprintf("set list names\n");
   SEXP sListNames;
   PROTECT(sListNames = allocVector(STRSXP, listNames.size()));
-  numAllocated ++;
-  for (unsigned int i = 0; i != listNames.size(); ++i){
+  numAllocated++;
+  for (unsigned int i = 0; i != listNames.size(); ++i) {
     SET_STRING_ELT(sListNames, i, mkChar(listNames[i].c_str()));
   }
   setAttrib(ret, R_NamesSymbol, sListNames);
@@ -448,22 +463,27 @@ SEXP readVCF2List(VCFInputFile* vin,
   // finish up
   UNPROTECT(numAllocated);
   // Rprintf("Unprotected: %d\n", (retListLen + 1));
-  return(ret);
+  return (ret);
 }
 
 /**
  * @param arg_fileName: a string character
  * @param arg_range: which range to extract. NOTE: only use first element
- * @param arg_annoType: allow annotation type, can be regular expression. (e.g. Synonymous|Nonsynonymous)
+ * @param arg_annoType: allow annotation type, can be regular expression. (e.g.
+ * Synonymous|Nonsynonymous)
  * @param arg_columns: a list of which columns to extract (e.g. CHROM, POS ...)
- * @param arg_infoTag: a list of which tag under INFO tag will be extracted (e.g. ANNO, ANNO_FULL, AC ...)
- * @param arg_indvTag: a list of which tag given in individual's column (e.g. GT, GD, GQ ...)
+ * @param arg_infoTag: a list of which tag under INFO tag will be extracted
+ * (e.g. ANNO, ANNO_FULL, AC ...)
+ * @param arg_indvTag: a list of which tag given in individual's column (e.g.
+ * GT, GD, GQ ...)
  */
-SEXP impl_readVCFToListByRange(SEXP arg_fileName, SEXP arg_range, SEXP arg_annoType, SEXP arg_columns, SEXP arg_infoTag, SEXP arg_indvTag){
+SEXP impl_readVCFToListByRange(SEXP arg_fileName, SEXP arg_range,
+                               SEXP arg_annoType, SEXP arg_columns,
+                               SEXP arg_infoTag, SEXP arg_indvTag) {
   // begin
-  std::string FLAG_fileName = CHAR(STRING_ELT(arg_fileName,0));
-  std::string FLAG_range = CHAR(STRING_ELT(arg_range,0));
-  std::string FLAG_annoType = CHAR(STRING_ELT(arg_annoType,0));
+  std::string FLAG_fileName = CHAR(STRING_ELT(arg_fileName, 0));
+  std::string FLAG_range = CHAR(STRING_ELT(arg_range, 0));
+  std::string FLAG_annoType = CHAR(STRING_ELT(arg_annoType, 0));
 
   std::set<std::string> FLAG_vcfColumn;
   std::vector<std::string> FLAG_infoTag, FLAG_indvTag;
@@ -472,7 +492,7 @@ SEXP impl_readVCFToListByRange(SEXP arg_fileName, SEXP arg_range, SEXP arg_annoT
   extractStringArray(arg_infoTag, &FLAG_infoTag);
   extractStringArray(arg_indvTag, &FLAG_indvTag);
 
-  //Rprintf( "range = %s\n", range.c_str());
+  // Rprintf( "range = %s\n", range.c_str());
   VCFExtractor vin(FLAG_fileName.c_str());
   if (FLAG_range.size())
     vin.setRangeList(FLAG_range.c_str());
@@ -480,39 +500,42 @@ SEXP impl_readVCFToListByRange(SEXP arg_fileName, SEXP arg_range, SEXP arg_annoT
     error("Please provide a range before we can continue.\n");
   };
   if (!FLAG_annoType.empty() && !vcfHasAnnotation(FLAG_fileName)) {
-    REprintf("Please use annotated VCF as input (cannot find ANNO in the INFO field);\n");
+    REprintf(
+        "Please use annotated VCF as input (cannot find ANNO in the INFO "
+        "field);\n");
     REprintf("Prefer using ANNO from https://github.com/zhanxw/anno  \n");
     SEXP ans = R_NilValue;
     return ans;
   }
-  
+
   if (FLAG_annoType.size()) {
     vin.setAnnoType(FLAG_annoType.c_str());
   }
   return readVCF2List(&vin, FLAG_vcfColumn, FLAG_infoTag, FLAG_indvTag);
-} // impl_readVCFToListByRange
+}  // impl_readVCFToListByRange
 
 /**
  * @param arg_fileName: a string character
  * @param arg_geneFile: which gene file to use
- * @param arg_geneName: which gene we are interested. (NOTE: only first one gene is used).
- * @param arg_annoType: allow annotation type, can be regular expression. (e.g. Synonymous|Nonsynonymous)
+ * @param arg_geneName: which gene we are interested. (NOTE: only first one gene
+ * is used).
+ * @param arg_annoType: allow annotation type, can be regular expression. (e.g.
+ * Synonymous|Nonsynonymous)
  * @param arg_columns: a list of which columns to extract (e.g. CHROM, POS ...)
- * @param arg_infoTag: a list of which tag under INFO tag will be extracted (e.g. ANNO, ANNO_FULL, AC ...)
- * @param arg_indvTag: a list of which tag given in individual's column (e.g. GT, GD, GQ ...)
+ * @param arg_infoTag: a list of which tag under INFO tag will be extracted
+ * (e.g. ANNO, ANNO_FULL, AC ...)
+ * @param arg_indvTag: a list of which tag given in individual's column (e.g.
+ * GT, GD, GQ ...)
  */
-SEXP impl_readVCFToListByGene(SEXP arg_fileName,
-                              SEXP arg_geneFile,
-                              SEXP arg_geneName,
-                              SEXP arg_annoType,
-                              SEXP arg_columns,
-                              SEXP arg_infoTag,
-                              SEXP arg_indvTag){
+SEXP impl_readVCFToListByGene(SEXP arg_fileName, SEXP arg_geneFile,
+                              SEXP arg_geneName, SEXP arg_annoType,
+                              SEXP arg_columns, SEXP arg_infoTag,
+                              SEXP arg_indvTag) {
   // begin
-  std::string FLAG_fileName = CHAR(STRING_ELT(arg_fileName,0));
-  std::string FLAG_geneFile = CHAR(STRING_ELT(arg_geneFile,0));
-  std::string FLAG_geneName = CHAR(STRING_ELT(arg_geneName,0));
-  std::string FLAG_annoType = CHAR(STRING_ELT(arg_annoType,0));
+  std::string FLAG_fileName = CHAR(STRING_ELT(arg_fileName, 0));
+  std::string FLAG_geneFile = CHAR(STRING_ELT(arg_geneFile, 0));
+  std::string FLAG_geneName = CHAR(STRING_ELT(arg_geneName, 0));
+  std::string FLAG_annoType = CHAR(STRING_ELT(arg_annoType, 0));
 
   std::set<std::string> FLAG_vcfColumn;
   std::vector<std::string> FLAG_infoTag, FLAG_indvTag;
@@ -522,17 +545,20 @@ SEXP impl_readVCFToListByGene(SEXP arg_fileName,
   extractStringArray(arg_indvTag, &FLAG_indvTag);
 
   if (!FLAG_annoType.empty() && !vcfHasAnnotation(FLAG_fileName)) {
-    REprintf("Please use annotated VCF as input (cannot find ANNO in the INFO field);\n");
+    REprintf(
+        "Please use annotated VCF as input (cannot find ANNO in the INFO "
+        "field);\n");
     REprintf("Prefer using ANNO from https://github.com/zhanxw/anno  \n");
     SEXP ans = R_NilValue;
     return ans;
   }
-  
+
   // Rprintf("vcfColumn.size() = %u\n", FLAG_vcfColumn.size());
   // Rprintf("vcfInfo.size() = %u\n", FLAG_infoTag.size());
   // Rprintf("vcfIndv.size() = %u\n", FLAG_indvTag.size());
   // also append sample names at the end
-  int retListLen = FLAG_vcfColumn.size() + FLAG_infoTag.size() + FLAG_indvTag.size() + 1;
+  int retListLen =
+      FLAG_vcfColumn.size() + FLAG_infoTag.size() + FLAG_indvTag.size() + 1;
   if (retListLen == 0) {
     return R_NilValue;
   }
@@ -548,7 +574,7 @@ SEXP impl_readVCFToListByGene(SEXP arg_fileName,
     range += geneRange.valueAt(i);
   }
 
-  REprintf( "range = %s\n", range.c_str());
+  REprintf("range = %s\n", range.c_str());
   VCFExtractor vin(FLAG_fileName.c_str());
   if (range.size())
     vin.setRangeList(range.c_str());
@@ -561,5 +587,4 @@ SEXP impl_readVCFToListByGene(SEXP arg_fileName,
   }
 
   return readVCF2List(&vin, FLAG_vcfColumn, FLAG_infoTag, FLAG_indvTag);
-} // end readVCF2List
-
+}  // end readVCF2List
